local L = AceLibrary("AceLocale-2.2"):new("Comments")


L:RegisterTranslations("enUS", function() return {
	["Comments"] = true,
    ["Description"] = "wowhead.com comments on quest details.",
} end)

L:RegisterTranslations("koKR", function() return {
	["Comments"] = "설명",
    ["Description"] = "wowhead.com의 퀘스트 상세 설명을 표시합니다.",
} end)

local moduleName = "Comments"
local Comments = nQuestLog:NewModule(moduleName,"AceEvent-2.0","AceHook-2.1")

local tablet = AceLibrary("Tablet-2.0")
local quixote = AceLibrary("Quixote-1.0")


function Comments:OnModuleLoad()
	self.menuName = L["Comments"]
	self.description = L["Description"]
	
	nQuestLog:RegisterDefaults(moduleName, "profile", {
		["enabled"] = true,
	})
end

function Comments:ToggleEnabled(v)
	self.db.profile.enabled = v
	if (v) then
		self:SecureHook(nQuestLog, "ShowLog")
		if nQuestLog:IsModuleActive('DetailsFrame') then
			self:SecureHook(nQuestLog:GetModule('DetailsFrame'), "UpdateQuestDetail")
		end
	else
		self:Unhook(nQuestLog, "ShowLog")
		if nQuestLog:IsModuleActive('DetailsFrame') then
			self:Unhook(nQuestLog:GetModule('DetailsFrame'), "UpdateQuestDetail")
		end

	end
end

function Comments:ShowLog(object, questid)
	--self.questid = questid
	if questid and LightHeaded and LightHeaded.IterateComments and nQuestLog:IsModuleEnabled("DetailsFrame") then
		self:ScheduleEvent(self.Update, 0, self) --Schedule an event because tablet bugs out otherwise.
	end
end

function Comments:UpdateQuestDetail(object)
	if (LightHeaded and LightHeaded.IterateComments) then
		self:Update()
	end
end


function Comments:GetQuestId()
	local questid
	if nQuestLog:IsModuleEnabled("DetailsFrame") then
		questid =  nQuestLog:GetModule("DetailsFrame").questid
	else
		questid = 1
	end
	
	return questid
end

function Comments:Update()
	-- This is pretty much a copy&paste of Comments.lua in FuBar_QuestsFu, made by kemayo.
	if not tablet:IsRegistered('nQuestLog_Comments') then
		tablet:Register('nQuestLog_Comments', 'detachedData', self.db.profile.data, 'cantAttach', true, 'dontHook', true,
			'hideWhenEmpty', true, 'showTitleWhenDetached', true, 'strata', self.db.profile.strata, 'minWidth', 300,
			'children', function()
				local questid = self:GetQuestId()
				-- Much of this was taken from LightHeaded itself.
				if questid then
					local title, level, tag = quixote:GetQuestById(questid)
					--local color = GetDifficultyColor(level)
					tablet:SetTitle("Comments")
					--tablet:SetTitleColor((color and color.r) or 1, (color and color.g) or 1, (color and color.b) or 1)

					local cat = tablet:AddCategory('text', 'LightHeaded', 'columns', 1, 'wrap', true, 'child_func', LightHeaded.OnHyperlinkClick, 'child_arg1', LightHeaded, 'justify', 'CENTER')

					local anycomments
					for idx, qid, cid, rating, indent, parent, date, poster, comment in LightHeaded:IterateComments(questid) do
						local link = ("comment:%s:%d:%d"):format(title, level, idx)
						
						cat:AddLine('text', ("|cFF66FF66[%s - %s]|r"):format(poster, date), 'arg2', link, 'wrap', true)
						cat:AddLine('text', comment, 'arg2', link, 'wrap', true)
						cat:AddLine('text', ' ', 'func', false) -- spacer.
						
						anycomments = true
					end
					
					if not anycomments then
						cat:AddLine('text', "No comments found...", 'func', false)
						return
					end
				end
			end)
		tablet:Open('nQuestLog_Comments')
	end
	tablet:Refresh('nQuestLog_Comments')
end
